@@ -1,19 +1,16 @@
 package Test::Mocha::Mock;
-{
-  $Test::Mocha::Mock::VERSION = '0.49_01';
-}
 # ABSTRACT: Mock objects
-
+$Test::Mocha::Mock::VERSION = '0.60_02';
 use strict;
 use warnings;
 
-use Carp 1.22           qw( croak );
+use Carp 1.22 qw( croak );
 use Test::Mocha::MethodCall;
 use Test::Mocha::MethodStub;
-use Test::Mocha::Types  qw( Matcher Slurpy );
-use Test::Mocha::Util   qw( extract_method_name find_caller find_stub
-                            getattr has_caller_package );
-use Types::Standard     qw( ArrayRef HashRef Str );
+use Test::Mocha::Types qw( Matcher Slurpy );
+use Test::Mocha::Util qw( extract_method_name find_caller find_stub
+  getattr has_caller_package );
+use Types::Standard qw( ArrayRef HashRef Str );
 use UNIVERSAL::ref;
 
 our $AUTOLOAD;
@@ -23,58 +20,62 @@ our $last_execution;
 
 # Classes for which mock isa() should return false
 my %Isnota = (
-    'Type::Tiny' => undef,
+    'Type::Tiny'                  => undef,
     'Moose::Meta::TypeConstraint' => undef,
 );
 
 # can() should always return a reference to the C<AUTOLOAD()> method
 my $CAN = Test::Mocha::MethodStub->new(
-    name => 'can',
-    args => [ Str ],
-)->executes(sub {
-    my ($self, $method_name) = @_;
-    return sub {
-        $AUTOLOAD = $method_name;
-        goto &AUTOLOAD;
-    };
-});
+    name       => 'can',
+    args       => [Str],
+    executions => [
+        sub {
+            my ( $self, $method_name ) = @_;
+            return sub {
+                $AUTOLOAD = $method_name;
+                goto &AUTOLOAD;
+            };
+        }
+    ],
+);
 
 # DOES() should always return true
 my $DOES_UC = Test::Mocha::MethodStub->new(
-    name => 'DOES',
-    args => [ Str ],
-)->returns(1);
+    name       => 'DOES',
+    args       => [Str],
+    executions => [ sub { 1 } ],
+);
 
 # does() should always return true
 my $DOES_LC = Test::Mocha::MethodStub->new(
-    name => 'does',
-    args => [ Str ],
-)->returns(1);
+    name       => 'does',
+    args       => [Str],
+    executions => [ sub { 1 } ],
+);
 
 # isa() should always returns true
 my $ISA = Test::Mocha::MethodStub->new(
-    name => 'isa',
-    args => [ Str ] ,
-)->returns(1);
-
+    name       => 'isa',
+    args       => [Str],
+    executions => [ sub { 1 } ],
+);
 
 sub new {
     # uncoverable pod
-    my $class = shift;
-    my $self  = bless {@_}, $class;
+    my ($class) = @_;
 
-    # ArrayRef[ MethodCall ]
-    $self->{calls} = [];
-
-    # $method_name => ArrayRef[ MethodStub ]
-    $self->{stubs} = {
-        can  => [ $CAN     ],
-        DOES => [ $DOES_UC ],
-        does => [ $DOES_LC ],
-        isa  => [ $ISA     ],
-    };
-
-    return $self;
+    my %args = (
+        # ArrayRef[ MethodCall ]
+        calls => [],
+        # $method_name => ArrayRef[ MethodStub ]
+        stubs => {
+            can  => [$CAN],
+            DOES => [$DOES_UC],
+            does => [$DOES_LC],
+            isa  => [$ISA],
+        },
+    );
+    return bless \%args, $class;
 }
 
 sub AUTOLOAD {
@@ -88,7 +89,7 @@ sub AUTOLOAD {
     {
         my $i = 0;
         my $seen_slurpy;
-        foreach ( @args ) {
+        foreach (@args) {
             if ( Slurpy->check($_) ) {
                 $seen_slurpy = 1;
                 last;
@@ -96,13 +97,13 @@ sub AUTOLOAD {
             $i++;
         }
         croak 'No arguments allowed after a slurpy type constraint'
-            if $i < $#args;
+          if $i < $#args;
 
-        if ( $seen_slurpy ) {
+        if ($seen_slurpy) {
             my $slurpy = $args[$i]->{slurpy};
             croak 'Slurpy argument must be a type of ArrayRef or HashRef'
-                unless $slurpy->is_a_type_of(ArrayRef)
-                    || $slurpy->is_a_type_of(HashRef);
+              unless $slurpy->is_a_type_of(ArrayRef)
+              || $slurpy->is_a_type_of(HashRef);
         }
     }
 
@@ -116,16 +117,16 @@ sub AUTOLOAD {
         invocant => $self,
         name     => $method_name,
         args     => \@args,
-        caller   => [ find_caller ],
+        caller   => [find_caller],
     );
-    push @$calls, $last_method_call;
+    push @{$calls}, $last_method_call;
 
     # find a stub to return a response
     my $stub = find_stub( $self, $last_method_call );
     if ( defined $stub ) {
         # save reference to stub execution so it can be restored
-        my $executions  = getattr( $stub, 'executions' );
-        $last_execution = $executions->[0] if @$executions > 1;
+        my $executions = getattr( $stub, 'executions' );
+        $last_execution = $executions->[0] if @{$executions} > 1;
 
         return $stub->do_next_execution( $self, @args );
     }
@@ -143,9 +144,9 @@ sub isa {
     return 1 if $class eq __PACKAGE__;
 
     # In order to allow mock methods to be called with other mocks as
-    # arguments, mocks cannot isa() type constraints, which are not allowed
-    # as arguments.
-    return if exists $Isnota{ $class };
+    # arguments, mocks cannot have isa() called with type constraints,
+    # which are not allowed as arguments.
+    return if exists $Isnota{$class};
 
     $AUTOLOAD = 'isa';
     goto &AUTOLOAD;
@@ -159,7 +160,7 @@ sub DOES {
     # when ref($mock) is called
     return 1 if $role eq __PACKAGE__;
 
-    return if !ref($self);
+    return if !ref $self;
 
     $AUTOLOAD = 'DOES';
     goto &AUTOLOAD;
@@ -176,8 +177,8 @@ sub can {
     goto &AUTOLOAD;
 }
 
-sub ref {
-    # uncoverable pod
+sub ref {  ## no critic (ProhibitBuiltinHomonyms)
+           # uncoverable pod
     $AUTOLOAD = 'ref';
     goto &AUTOLOAD;
 }
